excerpts.ExcerptType (Excerpt Type) — amici1

# `excerpts.ExcerptType` (Excerpt Type)

ExcerptType(id, name, build_method, template, attach_to_email, email_template, certifying, remark, body_template, content_type, primary, backward_compat, print_recipient, print_directly, shortcut, name_de, name_fr)

Master tables : excerpts.ExcerptTypes (Excerpt Types)

Slave tables : excerpts.ExcerptsByType (Excerpts)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : The designation of this excerpt type. One field for every language.

- Print method (build_method) : See lino.modlib.printing.mixins.PrintableType.build_method.

- Template (template) : The main template to be used when printing an excerpt of this type.

- Attach to email (attach_to_email) : Whether the printable file should be attached to the email when creating an email from a mailable of this type.

- Email template (email_template) : The template to use when sending this an excerpt of this type by email.

- Certifying (certifying) : Whether an excerpt of this type is a unique printout.

- Remark (remark) : See `<django.db.models.fields.TextField: remark>`.

- Body template (body_template) : The body template to use when printing an excerpt of this type.

- Model (content_type) : The database model for which this excerpt type is to be used.

- Primary (primary) : Whether this is the default type to use for this model. There’s at most one primary type per model. Enabling this field will automatically make the other types non-primary.

- Backward compatible (backward_compat) : Check this to have this in template context point to owner instead of excerpt.

- Print recipient (print_recipient) : Whether to print a recipient field in document.

- Print directly (print_directly) : See `<django.db.models.fields.BooleanField: print_directly>`.

- Excerpt shortcut (shortcut) : Optional pointer to a shortcut field. If this is not empty, then the given shortcut field will manage excerpts of this type.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Model (content_type_display) : See `lino_xl.lib.excerpts.models.ExcerptType.content_type_display`.

- Name (name_column) : See `lino_xl.lib.excerpts.models.ExcerptType.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.excerpts.models.ExcerptType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.excerpts.models.ExcerptType.overview`.

Referenced from excerpts.Excerpt.excerpt_type

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
name | Designation | The designation of this excerpt type. One field for every language.
build_method | Print method | See lino.modlib.printing.mixins.PrintableType.build_method.
template | Template | The main template to be used when printing an excerpt of this type.
attach_to_email | Attach to email | Whether the printable file should be attached to the email when creating an email from a mailable of this type.
email_template | Email template | The template to use when sending this an excerpt of this type by email.
certifying | Certifying | Whether an excerpt of this type is a unique printout.
remark | Remark |
body_template | Body template | The body template to use when printing an excerpt of this type.
content_type | Model | The database model for which this excerpt type is to be used.
primary | Primary | Whether this is the default type to use for this model. There’s at most one primary type per model. Enabling this field will automatically make the other types non-primary.
backward_compat | Backward compatible | Check this to have this in template context point to owner instead of excerpt.
print_recipient | Print recipient | Whether to print a recipient field in document.
print_directly | Print directly |
shortcut | Excerpt shortcut | Optional pointer to a shortcut field. If this is not empty, then the given shortcut field will manage excerpts of this type.
name_de | Designation (de) |
name_fr | Designation (fr) |
content_type_display | Model |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |